@@ -27,6 +27,7 @@
 #include <gtk/gtk.h>
 #include <libedataserver/libedataserver.h>
 
+#include <e-util/e-util.h>
 #include <mail/em-folder-tree.h>
 #include <mail/em-folder-utils.h>
 #include <libemail-engine/libemail-engine.h>
@@ -36,6 +37,7 @@
 #include <shell/e-shell-window.h>
 
 #include "server/e-ews-connection.h"
+#include "server/e-ews-connection-utils.h"
 #include "server/e-source-ews-folder.h"
 
 #include "e-ews-edit-folder-permissions.h"
@@ -174,8 +176,8 @@ e_ews_config_utils_run_in_thread_with_feedback_general (GtkWindow *parent,
 
 	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
-	spinner = gtk_spinner_new ();
-	gtk_spinner_start (GTK_SPINNER (spinner));
+	spinner = e_spinner_new ();
+	e_spinner_start (E_SPINNER (spinner));
 	gtk_box_pack_start (GTK_BOX (box), spinner, FALSE, FALSE, 0);
 
 	label = gtk_label_new (description);
@@ -264,6 +266,13 @@ struct _EEwsConfigUtilsAuthenticatorClass {
 	GObjectClass parent_class;
 };
 
+static gboolean
+ews_config_utils_authenticator_get_without_password (ESourceAuthenticator *auth)
+{
+	EEwsConfigUtilsAuthenticator *authenticator = (EEwsConfigUtilsAuthenticator *) auth;
+	return e_ews_connection_utils_get_without_password (authenticator->ews_settings);
+}
+
 static ESourceAuthenticationResult
 ews_config_utils_authenticator_try_password_sync (ESourceAuthenticator *auth,
                                                   const GString *password,
@@ -358,7 +367,10 @@ e_ews_config_utils_authenticator_class_init (EEwsConfigUtilsAuthenticatorClass *
 static void
 e_ews_config_utils_authenticator_authenticator_init (ESourceAuthenticatorInterface *iface)
 {
-	iface->try_password_sync = ews_config_utils_authenticator_try_password_sync;
+	iface->get_without_password =
+		ews_config_utils_authenticator_get_without_password;
+	iface->try_password_sync =
+		ews_config_utils_authenticator_try_password_sync;
 }
 
 static void
@@ -752,8 +764,8 @@ e_ews_config_utils_run_folder_sizes_dialog (GtkWindow *parent,
 
 	content_area = GTK_BOX (gtk_dialog_get_content_area (fsd->dialog));
 
-	spinner = gtk_spinner_new ();
-	gtk_spinner_start (GTK_SPINNER (spinner));
+	spinner = e_spinner_new ();
+	e_spinner_start (E_SPINNER (spinner));
 	spinner_label = gtk_label_new (_("Fetching folder list…"));
 
 	fsd->spinner_grid = GTK_GRID (gtk_grid_new ());
